@@ -5,8 +5,8 @@ import pandas as pd
 
 import nltk
 
-from util import get_nearest_value
-from bloomfilter import create_bf, jaccard_similarity, fill_pos_bf
+from ds_util.util import get_nearest_value
+from ds_util.bloomfilter import create_bf, jaccard_similarity, fill_pos_bf
 
 
 def anonymize_dataset(ldf,bf_len,k,bf_representation='binary'):
@@ -77,6 +77,8 @@ def rank_dataset(df_a,df_b,bf_representation='binary', bit_power=1):
       if bf_representation == 'binary':
 
         bf1 = np.unpackbits(bf1)
+        bf2 = np.unpackbits(bf2)
+
         if bit_power!=1:
           bf1 = bf1 * bit_power
           bf2 = bf2 * bit_power
@@ -123,7 +125,7 @@ def extract_sample_from_anonymized(rdf,sample_method='random1',
         df_m = rdf[(rdf.id1 == id) & (rdf.label == 1)]  # match
 
         if len(df_m) != 0:
-            sample_df.append(df_m.to_numpy()[0])
+            sample_df.append(df_m.to_numpy()[0]) # remover
             #add no match sample 
             if sample_method == 'random1':
                 unique_sim = df_nm.sim.unique()
